@@ -3,8 +3,7 @@ import logging
 from contextlib import contextmanager
 from typing import Dict
 
-from aws_lambda_powertools.helper.models import MetricUnit
-from aws_lambda_powertools.metrics.base import MetricManager
+from .base import MetricManager, MetricUnit
 
 logger = logging.getLogger(__name__)
 
@@ -30,9 +29,8 @@ class SingleMetric(MetricManager):
 
         from aws_lambda_powertools.metrics import SingleMetric, MetricUnit
         import json
-        metric = Single_Metric()
+        metric = Single_Metric(namespace="ServerlessAirline")
 
-        metric.add_namespace(name="ServerlessAirline")
         metric.add_metric(name="ColdStart", unit=MetricUnit.Count, value=1)
         metric.add_dimension(name="function_version", value=47)
 
@@ -63,24 +61,25 @@ class SingleMetric(MetricManager):
 
 
 @contextmanager
-def single_metric(name: str, unit: MetricUnit, value: float):
+def single_metric(name: str, unit: MetricUnit, value: float, namespace: str = None):
     """Context manager to simplify creation of a single metric
 
     Example
     -------
     **Creates cold start metric with function_version as dimension**
 
-        from aws_lambda_powertools.metrics import single_metric, MetricUnit
+        from aws_lambda_powertools import single_metric
+        from aws_lambda_powertools.metrics import MetricUnit
 
-        with single_metric(name="ColdStart", unit=MetricUnit.Count, value=1) as metric:
-                metric.add_namespace(name="ServerlessAirline")
+        with single_metric(name="ColdStart", unit=MetricUnit.Count, value=1, namespace="ServerlessAirline") as metric:
                 metric.add_dimension(name="function_version", value=47)
 
     **Same as above but set namespace using environment variable**
 
         $ export POWERTOOLS_METRICS_NAMESPACE="ServerlessAirline"
 
-        from aws_lambda_powertools.metrics import single_metric, MetricUnit
+        from aws_lambda_powertools import single_metric
+        from aws_lambda_powertools.metrics import MetricUnit
 
         with single_metric(name="ColdStart", unit=MetricUnit.Count, value=1) as metric:
                 metric.add_dimension(name="function_version", value=47)
@@ -93,6 +92,8 @@ def single_metric(name: str, unit: MetricUnit, value: float):
         `aws_lambda_powertools.helper.models.MetricUnit`
     value : float
         Metric value
+    namespace: str
+        Namespace for metrics
 
     Yields
     -------
@@ -106,7 +107,7 @@ def single_metric(name: str, unit: MetricUnit, value: float):
     """
     metric_set = None
     try:
-        metric: SingleMetric = SingleMetric()
+        metric: SingleMetric = SingleMetric(namespace=namespace)
         metric.add_metric(name=name, unit=unit, value=value)
         yield metric
         logger.debug("Serializing single metric")
